@@ -23,14 +23,13 @@
 from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Pango
 
 from ccm.Constants import TableDef, TableX, KeyModifier, Edges, ImageStock, FilterName, FilterLongDesc, FilterValue, FilterAll, DataDir
 from ccm.Conflicts import KeyConflict, ButtonConflict, EdgeConflict
 from ccm.Widgets import CellRendererColor, ModifierSelector, SingleEdgeSelector, KeyGrabber, MatchButton, FileButton, ErrorDialog
 from ccm.Utils import Image, ActionImage, SizedButton, GlobalUpdater, PureVirtualError, SettingKeyFunc, EnumSettingKeyFunc, HasOnlyType, GetSettings, GetAcceleratorName
 
-from cgi import escape as protect_pango_markup
-
 import locale
 import gettext
 locale.setlocale(locale.LC_ALL, "")
@@ -110,14 +109,14 @@ class Setting(object):
             return
 
         label = Gtk.Label()
-        desc = protect_pango_markup (self.Setting.ShortDesc)
+        desc = GLib.markup_escape_text(self.Setting.ShortDesc)
         style = "%s"
         if self.Setting.Integrated:
             style = "<i>%s</i>"
         label.set_markup(style % desc)
         label.props.xalign = 0
         label.set_size_request(160, -1)
-        label.props.wrap_mode = Gtk.WrapMode.WORD
+        label.props.wrap_mode = Pango.WrapMode.WORD
         label.set_line_wrap(True)
         self.Label = label
 
@@ -966,7 +965,7 @@ class KeySetting (EditableActionSetting):
     def HandleDialogText (self, accel):
         name = self.ReorderKeyString (accel)
         if len (accel) != len (name):
-            accel = protect_pango_markup (accel)
+            accel = GLib.markup_escape_text(accel)
             ErrorDialog (self.Widget.get_toplevel (),
                          _("\"%s\" is not a valid shortcut") % accel)
             return
@@ -1149,7 +1148,7 @@ class ButtonSetting (EditableActionSetting):
 
     def HandleDialogText (self, button):
         def ShowErrorDialog (button):
-            button = protect_pango_markup (button)
+            button = GLib.markup_escape_text(button)
             ErrorDialog (self.Widget.get_toplevel (),
                          _("\"%s\" is not a valid button") % button)
         if button.lower ().strip () in ("", "disabled", "none"):
@@ -1276,7 +1275,7 @@ class ButtonSetting (EditableActionSetting):
                                          buttons = Gtk.ButtonsType.YES_NO,
                                          title = _("Warning"))
 
-            warning.set_markup (GLib.markup_escape_text (_("Using Button1 without modifiers can \
+            warning.set_markup(GLib.markup_escape_text(_("Using Button1 without modifiers can \
 prevent any left click and thus break your configuration. Do you really want \
 to set \"%s\" button to Button1 ?") % self.Setting.ShortDesc))
 
@@ -1330,7 +1329,7 @@ class EdgeSetting (EditableActionSetting):
                 valid = False
                 break
         if not valid:
-            mask = protect_pango_markup (mask)
+            mask = GLib.markup_escape_text(mask)
             ErrorDialog (self.Widget.get_toplevel (),
                          _("\"%s\" is not a valid edge mask") % mask)
             return
