@@ -27,7 +27,7 @@
 #include <gmock/gmock.h>
 
 #include <boost/shared_array.hpp>
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 
 #include <xorg/gtest/xorg-gtest.h>
 #include <compiz-xorg-gtest.h>
@@ -36,6 +36,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
+using namespace boost::placeholders;
 using ::testing::MatchResultListener;
 using ::testing::MakeMatcher;
 using ::testing::Matcher;
@@ -83,7 +84,7 @@ namespace
     void SetUserTime (Display *dpy, Window w, Time time)
     {
 	Atom _NET_WM_USER_TIME = XInternAtom (dpy, "_NET_WM_USER_TIME", false);
-	unsigned int value = (unsigned int) time;
+	unsigned long value = (unsigned long) time;
 
 	XChangeProperty (dpy, w,
 			 _NET_WM_USER_TIME,
